@@ -20,7 +20,7 @@
 
 #define QT_FEATURE_reduce_exports 1
 
-#define QT_FEATURE_reduce_relocations -1
+#define QT_FEATURE_no_direct_extern_access -1
 
 #define QT_FEATURE_sse2 -1
 
@@ -56,8 +56,12 @@
 
 #define QT_FEATURE_avx512vbmi -1
 
+#define QT_FEATURE_avx512vbmi2 -1
+
 #define QT_FEATURE_aesni -1
 
+#define QT_FEATURE_vaes -1
+
 #define QT_FEATURE_rdrnd -1
 
 #define QT_FEATURE_rdseed -1
